@@ -4,9 +4,15 @@ from tokenizer_tools.conllz.sentence import SentenceX
 
 
 def read_conllx_from_string(conllx_string):
+    # default is -1 for there always +1 for block which is not right for start block
+    last_block_line_num = -1
+
     raw_sentence_list = conllx_string.split("\n\n")
 
     for raw_sentence in raw_sentence_list:
+        # +1 for there is a empty line between block
+        last_block_line_num += 1
+
         cleaned_sentence = raw_sentence.strip()
 
         if not cleaned_sentence:
@@ -18,7 +24,15 @@ def read_conllx_from_string(conllx_string):
         for index, raw_line in enumerate(raw_line_list):
             if index == 0:
                 meta_string = raw_line.strip("#\t\n ")
-                meta_data = json.loads(meta_string)
+                try:
+                    meta_data = json.loads(meta_string)
+                except json.decoder.JSONDecodeError as e:
+                    raise ValueError(
+                        "Head line JSON parsing failed at line {}: {}".format(
+                            last_block_line_num + index + 1, e
+                        )
+                    )
+
                 sentence.id = meta_data.pop("id")
                 sentence.meta = meta_data
 
@@ -33,6 +47,9 @@ def read_conllx_from_string(conllx_string):
 
             sentence.write_as_row(item)
 
+        # +1 for index start from 0
+        last_block_line_num += index + 1
+
         yield sentence
 
 
